@@ -15,7 +15,8 @@ import __builtin__
 infinity = float('inf')
 
 
-def iterate_overlapping_subsequences(iterable, length=2, wrap_around=False):
+def iterate_overlapping_subsequences(iterable, length=2, wrap_around=False,
+                                     lazy_tuple=False):
     '''
     Iterate over overlapping subsequences from the iterable.
         
@@ -28,7 +29,22 @@ def iterate_overlapping_subsequences(iterable, length=2, wrap_around=False):
     
     If `wrap_around=True`, the result would be `[(0, 1, 2), (1,
     2, 3), (2, 3, 0), (3, 0, 1)]`.
+    
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
     '''
+    iterator = _iterate_overlapping_subsequences(
+        iterable=iterable, length=length, wrap_around=wrap_around
+    )
+
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    else:
+        return iterator
+
+
+def _iterate_overlapping_subsequences(iterable, length, wrap_around):
+
     if length == 1:
         for item in iterable:
             yield item
@@ -68,7 +84,7 @@ def iterate_overlapping_subsequences(iterable, length=2, wrap_around=False):
         yield tuple(deque)
         
     
-def shorten(iterable, n):
+def shorten(iterable, n, lazy_tuple=False):
     '''
     Shorten an iterable to length `n`.
     
@@ -76,7 +92,19 @@ def shorten(iterable, n):
     iterable stops iteration by itself.)
     
     `n` may be infinite.
+
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
     '''
+    iterator = _shorten(iterable=iterable, n=n)
+
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    else:
+        return iterator
+
+
+def _shorten(iterable, n):
 
     if n == infinity:
         for thing in iterable:
@@ -94,7 +122,7 @@ def shorten(iterable, n):
             raise StopIteration
         
         
-def enumerate(reversible, reverse_index=False):
+def enumerate(reversible, reverse_index=False, lazy_tuple=False):
     '''
     Iterate over `(i, item)` pairs, where `i` is the index number of `item`.
     
@@ -102,7 +130,19 @@ def enumerate(reversible, reverse_index=False):
     reverse index, by specifying `reverse_index=True`. This causes `i` to count
     down to zero instead of up from zero, so the `i` of the last member will be
     zero.
+    
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
     '''
+    iterator = _enumerate(reversible=reversible, reverse_index=reverse_index)
+
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    else:
+        return iterator
+
+    
+def _enumerate(reversible, reverse_index):
     if reverse_index is False:
         return __builtin__.enumerate(reversible)
     else:
@@ -136,8 +176,22 @@ def get_length(iterable):
     return i
 
 
-def iter_with(iterable, context_manager):
-    '''Iterate on `iterable`, `with`ing the context manager on every `next`.'''
+def iter_with(iterable, context_manager, lazy_tuple=False):
+    '''
+    Iterate on `iterable`, `with`ing the context manager on every `next`.
+    
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
+    '''
+    iterator = _iter_with(iterable=iterable, context_manager=context_manager)
+
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    else:
+        return iterator
+
+    
+def _iter_with(iterable, context_manager):
     
     iterator = iter(iterable)
     
@@ -145,11 +199,8 @@ def iter_with(iterable, context_manager):
         
         with context_manager:
             next_item = next(iterator)
-            # You may notice that we are not `except`ing a `StopIteration`
-            # here; If we get one, it'll just get propagated and end *this*
-            # iterator. todo: I just realized this will probably cause a bug
-            # where `__exit__` will get the `StopIteration`! Make failing tests
-            # and fix.
+            # Recycling `StopIteration` exception. (Assuming the context
+            # manager doesn't have special treatment for it.)
         
         yield next_item
         
@@ -167,13 +218,18 @@ def get_items(iterable, n, container_type=tuple):
     return container_type(shorten(iterable, n))
 
 
-def double_filter(filter_function, iterable):
+def double_filter(filter_function, iterable, lazy_tuple=False):
     '''
-    Filter an `iterable` into two lists according to a `filter_function`.
+    Filter an `iterable` into two iterables according to a `filter_function`.
     
     This is similar to the builtin `filter`, except it returns a tuple of two
     iterators, the first iterating on items that passed the filter function,
     and the second iterating on items that didn't.
+    
+    Note that this function is not thread-safe. (You may not consume the two
+    iterators on two separate threads.)
+    
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
     '''
     iterator = iter(iterable)
     
@@ -202,7 +258,13 @@ def double_filter(filter_function, iterable):
                 else:
                     yield value
                 
-    return (make_true_iterator(), make_false_iterator())
+    iterators = (make_true_iterator(), make_false_iterator())
+    
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return tuple(map(nifty_collections.LazyTuple, iterators))
+    else:
+        return iterators
 
 
 
@@ -221,7 +283,7 @@ def get_ratio(filter_function, iterable):
     
 
 def fill(iterable, fill_value=None, fill_value_maker=None, length=infinity,
-         sequence_type=None):
+         sequence_type=None, lazy_tuple=False):
     '''
     Iterate on `iterable`, and after it's exhaused, yield fill values.
     
@@ -232,19 +294,26 @@ def fill(iterable, fill_value=None, fill_value_maker=None, length=infinity,
     If `length` is given, shortens the iterator to that length.
     
     If `sequence_type` is given, instead of returning an iterator, this
-    function will return a sequence of that type.
+    function will return a sequence of that type. If `lazy_tuple=True`, uses a
+    `LazyTuple`. (Can't use both options together.)
     '''
+    # Validating user input:
+    assert (sequence_type is None) or (lazy_tuple is False)
+    
     iterator = _fill(iterable, fill_value=fill_value,
                      fill_value_maker=fill_value_maker, 
                      length=length)
     
-    if sequence_type is None:
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    elif sequence_type is None:
         return iterator
     else:
         return sequence_type(iterator)
     
     
-def _fill(iterable, fill_value=None, fill_value_maker=None, length=infinity):
+def _fill(iterable, fill_value, fill_value_maker, length):
     if fill_value_maker is not None:
         assert fill_value is None
     else:
@@ -267,6 +336,30 @@ def _fill(iterable, fill_value=None, fill_value_maker=None, length=infinity):
                 yield fill_value_maker()
                 
     
+def call_until_exception(function, exception, lazy_tuple=False):
+    '''
+    Iterate on values returned from `function` until getting `exception`.
+    
+    If `lazy_tuple=True`, returns a `LazyTuple` rather than an iterator.
+    '''
+    iterator = _call_until_exception(function, exception)
+    if lazy_tuple:
+        from python_toolbox import nifty_collections # Avoiding circular import.
+        return nifty_collections.LazyTuple(iterator)
+    else:
+        return iterator
+    
+
+def _call_until_exception(function, exception):
+    from python_toolbox import sequence_tools
+    exceptions = sequence_tools.to_tuple(exception, item_type=type)
+    try:
+        while True:
+            yield function()
+    except exceptions:
+        raise StopIteration
+
+    
 def get_single_if_any(iterable,
                       exception_on_multiple=Exception('More than one value '
                                                       'not allowed.')):
