@@ -9,7 +9,8 @@ from .misc_tools import (
     is_magic_variable_name, get_actual_type, is_number, identity_function,
     do_nothing, OwnNameDiscoveringDescriptor, find_clear_place_on_circle,
     general_sum, general_product, is_legal_email_address, is_type, NonInstatiable,
-    repeat_getattr, add_extension_if_plain, set_attributes, pocket
+    repeat_getattr, add_extension_if_plain, set_attributes, pocket,
+    decimal_number_from_string
 )
 from . import name_mangling
 from .proxy_property import ProxyProperty
\ No newline at end of file
