@@ -49,6 +49,8 @@ def _with_lock(method, *args, **kwargs):
         return method(*args, **kwargs)
 
     
+
+@comparison_tools.total_ordering    
 class LazyTuple(collections.Sequence, object):
     '''
     A lazy tuple which requests as few values as possible from its iterator.
@@ -73,10 +75,13 @@ class LazyTuple(collections.Sequence, object):
     Some actions require exhausting the entire iterator. For example, checking
     the `LazyTuple` length, or doing indexex access with a negative index.
     (e.g. asking for the seventh-to-last element.)
+    
+    If you're passing in an iterator you definitely know to be infinite,
+    specify `definitely_infinite=False`.
     '''
     
-    def __init__(self, iterable):
-        was_given_a_sequence = sequence_tools.is_sequence(iterable) and \
+    def __init__(self, iterable, definitely_infinite=False):
+        was_given_a_sequence = isinstance(iterable, collections.Sequence) and \
                                not isinstance(iterable, LazyTuple)
         
         self.exhausted = True if was_given_a_sequence else False
@@ -88,18 +93,26 @@ class LazyTuple(collections.Sequence, object):
         self._iterator = None if was_given_a_sequence else iter(iterable)
         '''The internal iterator from which we get data.'''
         
+        self.definitely_infinite = definitely_infinite
+        '''
+        The iterator is definitely infinite.
+        
+        The iterator might still be infinite if this is `False`, but if it's
+        `True` then it's definitely infinite.
+        '''
+        
         self.lock = threading.Lock()
         '''Lock used while exhausting to make `LazyTuple` thread-safe.'''
         
         
     @classmethod
-    def factory(cls, callable):
+    def factory(cls, definitely_infinite=False):
         '''
         Decorator to make generators return a `LazyTuple`.
                 
         Example:
         
-            @LazyTuple.factory
+            @LazyTuple.factory()
             def my_generator():
                 yield 'hello'; yield 'world'; yield 'have'; yield 'fun'
         
@@ -108,8 +121,9 @@ class LazyTuple(collections.Sequence, object):
         '''
         
         def inner(function, *args, **kwargs):
-            return cls(callable(*args, **kwargs))
-        return decorator_tools.decorator(inner, callable)
+            return cls(function(*args, **kwargs),
+                       definitely_infinite=definitely_infinite)
+        return decorator_tools.decorator(inner)
         
     
     @property
@@ -169,8 +183,11 @@ class LazyTuple(collections.Sequence, object):
             
     
     def __len__(self):
-        self.exhaust()
-        return len(self.collected_data)
+        if self.definitely_infinite:
+            return 0 # Unfortunately infinity isn't supported.
+        else:
+            self.exhaust()
+            return len(self.collected_data)
 
     
     def __eq__(self, other):
@@ -270,12 +287,11 @@ class LazyTuple(collections.Sequence, object):
         
         Note: Hashing the `LazyTuple` will completely exhaust it.
         '''
-        self.exhaust()
-        return hash(tuple(self))
-    
-    
-comparison_tools.total_ordering(LazyTuple)
+        if self.definitely_infinite:
+            raise TypeError("An infinite `LazyTuple` isn't hashable.")
+        else:
+            self.exhaust()
+            return hash(tuple(self))
+        
 
-if hasattr(collections, 'Sequence'):
-    collections.Sequence.register(LazyTuple)
-    
\ No newline at end of file
+collections.Sequence.register(LazyTuple)
\ No newline at end of file
