@@ -5,6 +5,9 @@
 
 import weakref
 
+from python_toolbox import misc_tools
+
+
 def _is_weakreffable(thing):
     '''Return whether a weakref can be created to `thing`.'''
     try:
@@ -22,10 +25,10 @@ class A(object):
         pass
 
     
+@misc_tools.set_attributes(count=0)
 def counter(*args, **kwargs):
     '''Function that returns a higher number every time it's called.'''
-    if not hasattr(counter, 'count'):
-        counter.count = 0
-    result = counter.count
-    counter.count += 1
-    return result
+    try:
+        return counter.count
+    finally:
+        counter.count += 1
