@@ -1,4 +1,4 @@
-# Copyright 2009-2013 Ram Rachum.
+# Copyright 2009-2014 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''
@@ -25,7 +25,6 @@ class TempWorkingDirectorySetter(TempValueSetter):
         
         `working_directory` is the temporary working directory to use.
         '''
-        assert isinstance(working_directory, str)
         TempValueSetter.__init__(self,
                                  (os.getcwd, os.chdir),
-                                 value=working_directory)
\ No newline at end of file
+                                 value=str(working_directory))
\ No newline at end of file
